@@ -7,17 +7,17 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
  *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the GNU
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301
+ * USA
  */
 #include "ibustext.h"
 
@@ -272,8 +272,18 @@ ibus_text_get_text (IBusText *text)
     return text->text;
 }
 
-const IBusAttrList *
+IBusAttrList *
 ibus_text_get_attributes (IBusText *text)
 {
     return text->attrs;
 }
+
+void
+ibus_text_set_attributes (IBusText     *text,
+                          IBusAttrList *attrs)
+{
+    if (text->attrs)
+        g_object_unref (text->attrs);
+    text->attrs = attrs;
+    g_object_ref_sink (text->attrs);
+}
